pub struct HeaderAttr {
pub attr: PerfEventAttr,
pub ids: Vec<u64>,
}Expand description
PERF_RECORD_HEADER_ATTR - Contains event attribute and associated event IDs
Used in pipe mode to transmit event attribute information that would otherwise be in the attrs section of a regular perf.data file.
Fields
attr: PerfEventAttrids: Vec<u64>Implementations