pub struct HeaderFeature {
pub feature: Feature,
pub data: Vec<u8>,
}Expand description
PERF_RECORD_HEADER_FEATURE - Contains feature section data
Used in pipe mode to transmit feature data that would otherwise be in the feature sections at the end of a regular perf.data file.
Fields
feature: Featuredata: Vec<u8>Implementations